@@ -1,6 +1,6 @@
+pub mod errors;
 pub mod instructions;
 pub mod state;
-pub mod errors;
 
 use {anchor_lang::prelude::*, instructions::*};
 
@@ -14,10 +14,6 @@ pub mod cardinal_time_invalidator {
         init::handler(ctx, ix)
     }
 
-    pub fn set_expiration(ctx: Context<SetExpirationCtx>) -> Result<()> {
-        set_expiration::handler(ctx)
-    }
-
     pub fn extend_expiration(ctx: Context<ExtendExpirationCtx>, payment_amount: u64) -> Result<()> {
         extend_expiration::handler(ctx, payment_amount)
     }
@@ -29,4 +25,4 @@ pub mod cardinal_time_invalidator {
     pub fn close(ctx: Context<CloseCtx>) -> Result<()> {
         close::handler(ctx)
     }
-}
\ No newline at end of file
+}
